@@ -162,80 +162,3 @@ def opt_geometry(path: str, model_name:str, gpu_idx=0, opt_tol=0.003, opt_steps=
         for mol in out_mols:
             f.write(mol.write('sdf'))
     return outpath
-
-
-if __name__ == "__main__":
-    import os
-    from openbabel import pybel
-    import argparse
-
-    
-    ev2hatree = 1/27.211385  #1 Hartree = 27.211385 eV
-    parser = argparse.ArgumentParser(description="ASE interface for calculation G for ANI2xt and AIMNET")
-    parser.add_argument("path", type=str, help="Input sdf file")
-    parser.add_argument("model", type=str, help="ANI2xt or AIMNET")
-    parser.add_argument("--gpu_idx", default=0, type=int, help="GPU cuda index")
-    parser.add_argument("--convergence_threshold", default=0.003, type=float, 
-                        help="Convergence_threshold for geometry optimization")
-    parser.add_argument("--opt_steps", default=10000, type=int,
-                        help="Maximum geometry optimizaiton steps")
-
-    args = parser.parse_args()
-    path = args.path
-    model_name = args.model
-    gpu_idx = args.gpu_idx
-    # idx_t = args.idx_t
-    opt_steps = args.opt_steps
-    opt_tol = args.convergence_threshold
-
-    dir = os.path.dirname(path)
-    basename = os.path.basename(path).split(".")[0] + f"_{model_name}_opt.sdf"
-    outpath = os.path.join(dir, basename)
-    out_mols = []
-    mols_failed = []
-    species2numbers = {'H':1, 'C':6, 'N':7, 'O':8, 'F':9, 'Si':14, 'P':15,
-                       'S':16, 'Cl':17, 'As':33, 'Se':34, 'Br':35, 'I':53, 'B':5}
-    numbers2species = dict([(val, key) for (key, val) in species2numbers.items()])
-
-    if torch.cuda.is_available():
-        device = torch.device(f"cuda:{gpu_idx}")
-    else:
-        device = torch.device("cpu")
-    if model_name == "ANI2xt":
-        dict_path = os.path.join(root, "models/ani2xt_seed0.pt")
-        model = EnForce_ANI('ANI2xt', dict_path, device=device)
-    elif model_name == "AIMNET":
-        dict_path = os.path.join(root, "models/aimnet2nqed_pc14iall_b97m_sae.jpt")
-        model = EnForce_ANI('AIMNET', dict_path, device=device)
-    elif model_name == "ANI2x":
-        calculator = torchani.models.ANI2x().to(device).ase()
-    else:
-        raise ValueError("model has to be 'ANI2x', 'ANI2xt' or 'AIMNET'")
-
-    mols = pybel.readfile("sdf", path)
-    for mol in mols:
-        coord = [a.coords for a in mol.atoms]
-        charge = mol.charge
-        species = [numbers2species[a.atomicnum] for a in mol.atoms]
-        atoms = Atoms(species, coord)
-        
-        if model_name != "ANI2x":
-            calculator = Calculator(model, charge)
-        atoms.set_calculator(calculator)
-
-
-        opt = BFGS(atoms)
-        opt.run(fmax=opt_tol, steps=opt_steps)
-        e = atoms.get_potential_energy()
-        mol.data['E_hatree'] = e * ev2hatree
-
-        #Updating ASE atoms coordinates into pybel mol
-        coord = atoms.get_positions()
-        for atom, c in zip(mol.atoms, coord):
-            atom.OBAtom.SetVector(*c)
-        out_mols.append(mol)
-
-    print(len(out_mols))
-    with open(outpath, 'w+') as f:
-        for mol in out_mols:
-            f.write(mol.write('sdf'))
