@@ -19,7 +19,7 @@ try:
     from openeye import oequacpac
     from openeye import oeomega
 except:
-    warnings.warn("Openeye software is not available.")
+    pass
 from tqdm import tqdm
 
 
